/* This file has been automatically generated by trac-rescope. Do not edit. */
/* Avoid layout issues with side fieldsets, see #8866 */
#trac-container .admin h1,#trac-container .admin h2
{
  margin-top:0;
}

#trac-container #content.admin h1
{
  float:left;
}

#trac-container #tabs
{
  background:#f7f7f0;
  border:1px solid black;
  border-color:#ccc #666 #666 #ccc;
  clear:left;
  margin:1em 0 2em;
  padding:.5em 0 0;
  float:left;
  width:12em;
}

#trac-container #tabs ul
{
  list-style:none;
  margin:0 0 .5em;
  padding:0;
}

#trac-container #tabs li
{
  color:#999;
  font-size:90%;
  font-weight:bold;
  margin:0;
  padding:.1em 5px;
}

#trac-container #tabs li li
{
  color:#000;
  font-size:110%;
  font-weight:normal;
  margin:0 -3px;
  padding:1px 0 1px 10px;
}

#trac-container #tabs li li.active
{
  background:#ddc;
  border:1px solid;
  border-color:#ccc #000 #666 #ccc;
  padding:0 0 0 9px;
}

#trac-container #tabs :link,#trac-container #tabs :visited
{
  border:none;
  display:block;
}

#trac-container #tabs :link:hover,#trac-container #tabs :visited:hover
{
  background:transparent;
  color:#000;
}

#trac-container #tabcontent
{
  padding:.4em 0 .4em 2em;
  margin-left:12em;
  min-height:300px;
}

#trac-container #tabcontent h2
{
  color:#333;
}

#trac-container #tabcontent form
{
  overflow:auto;
  padding:0 1px;
}

#trac-container p.help
{
  color:#666;
  font-size:90%;
  margin:1em .5em .5em;
}

#trac-container #enumlist tbody td
{
  vertical-align:middle;
}

#trac-container #tabcontent form.addnew
{
  clear:right;
  float:right;
  margin:-2em 0 2em 2em;
  width:33%;
  overflow:visible;
  padding:0;
}

#trac-container #tabcontent form.mod
{
  margin-top:1em;
  overflow:visible;
  padding:0;
}

#trac-container form.mod fieldset
{
  margin:0;
}

#trac-container form.mod .field
{
  margin:.5em 0;
}

#trac-container form .field em
{
  color:#888;
  font-size:smaller;
}

#trac-container form .field .disabled em
{
  color:#d7d7d7;
}

#trac-container table.listing
{
  clear:none;
}

#trac-container table.listing .sel,#trac-container table.listing .default
{
  text-align:center;
  width:1%;
}

#trac-container table.listing .num
{
  text-align:right;
  width:1%;
}

/* Plugins panel */
#trac-container form#addplug
{
  width:35%;
}

#trac-container .plugin
{
  background:#f7f7f7;
  border:1px solid #d7d7d7;
  margin:0 0 2em;
  padding:2px .5em;
  text-align:left;
}

#trac-container .plugin > .foldable
{
  margin:.5em 0;
  color:#b00;
}

#trac-container .plugin .buttons
{
  margin-top:0;
  text-align:right;
}

#trac-container .plugin .uninstall
{
  margin-top:-2.6em;
  padding:0;
}

#trac-container .plugin .summary,#trac-container .plugin .info
{
  padding-left:16px;
  color:#999;
  font-size:80%;
}

#trac-container .plugin .summary
{
  margin:-.5em 0 .5em;
}

#trac-container .plugin .info
{
  margin:1em 0 .5em;
}

#trac-container .plugin .info dt
{
  float:left;
  width:7em;
}

#trac-container .plugin .info dd
{
  padding:0;
  margin:0;
}

#trac-container .plugin .listing
{
  width:100%;
}

#trac-container .plugin .listing td
{
  background:#fff;
}

#trac-container .trac-heading
{
  margin:0;
}

#trac-container .trac-name
{
  font-family:monospace;
}

#trac-container .trac-toggler
{
  color:#000;
  font-weight:normal;
}

#trac-container .trac-toggler :link,#trac-container .trac-toggler :visited,#trac-container .trac-toggler :link:hover,#trac-container .trac-toggler :visited:hover
{
  border:none;
  padding:0;
}

#trac-container .trac-module .trac-heading
{
  padding-left:16px;
  color:#888;
}

#trac-container .trac-module .trac-heading.foldable
{
  text-indent:-16px;
}

#trac-container .trac-module > div
{
  margin-left:1em;
}

#trac-container .trac-component .trac-heading
{
  margin-left:2em;
  padding-left:16px;
}

#trac-container .trac-component .trac-heading.foldable
{
  text-indent:-16px;
}

#trac-container .trac-component > div
{
  margin-left:3em;
}

#trac-container .trac-summary
{
  color:#888;
}

#trac-container table.trac-pluglist td
{
  padding-left:1em;
}

/* Perm Panel */
#trac-container #permlist div
{
  float:left;
  min-width:13em;
  max-width:33%;
  padding:0 2em 0 0;
}

#trac-container fieldset tr.field th
{
  text-align:right;
}