/* This file has been automatically generated by trac-rescope. Do not edit. */
/* About page */
#trac-container #content.about p.copyright
{
  color:#999;
  font-size:90%;
}

#trac-container #content.about h2
{
  margin-top:2em;
}

#trac-container #content.about table
{
  margin-top:0;
  width:auto;
}

#trac-container #content.about table th,#trac-container #content.about table td
{
  font-size:90%;
}

#trac-container #content.about table th
{
  background:#f7f7f7;
  font-weight:bold;
  vertical-align:top;
  white-space:nowrap;
}

#trac-container #content.about #plugins tr.disabled th,#trac-container #content.about #plugins tr.disabled td
{
  color:#999;
}

#trac-container #content.about #plugins td.file
{
  color:#666;
}

#trac-container #content.about #config th,#trac-container #content.about #config td
{
  border:1px solid #ddd;
  padding:3px;
}

#trac-container #content.about #config tr.modified
{
  background:#ffd;
}

#trac-container #content.about #config tr.modified td.value
{
  font-style:italic;
}

#trac-container #content.about #config td.doc
{
  padding:3px 1em;
}