/* This file has been automatically generated by trac-rescope. Do not edit. */
#trac-container #content.prefs #tabs
{
  list-style:none;
  margin:2em 1em 0;
  padding:1px;
}

#trac-container #content.prefs #tabs li
{
  background:#e6e6e6;
  border:1px solid;
  border-color:#ccc #666 #ccc #ccc;
  color:#666;
  position:relative;
  bottom:-1px;
  float:left;
  font-size:90%;
  margin:0 .5em;
  padding:.2em 1em .3em;
}

#trac-container #content.prefs #tabs :link,#trac-container #content.prefs #tabs :visited
{
  border:none;
  color:#999;
}

#trac-container #content.prefs #tabs :link:hover,#trac-container #content.prefs #tabs :visited:hover
{
  background:transparent;
  color:#333;
}

#trac-container #content.prefs #tabs li.active
{
  background:#fff;
  border-bottom:1px solid #fff;
}

#trac-container #content.prefs #tabs #tab_advanced
{
  float:right;
}

#trac-container #content.prefs #tabcontent
{
  background:url(../../common/vgradient.png) 0 1px repeat-x;
  border-top:1px solid #ccc;
  clear:left;
  padding:20px 5px;
}

* html #trac-container #content.prefs #tabcontent
{
  padding-top:0;
}

#trac-container #content.prefs div.field
{
  margin-bottom:1em;
}

#trac-container #content.prefs tr.field th
{
  text-align:right;
  vertical-align:middle;
  white-space:nowrap;
}