/* This file has been automatically generated by trac-rescope. Do not edit. */
/* Changeset overview */
#trac-container #overview .files
{
  padding-top:1em;
}

#trac-container #overview .files ul
{
  margin:0;
  padding:0;
}

#trac-container #overview .files li
{
  list-style-type:none;
}

#trac-container #overview .files li .comment
{
  display:none;
}

#trac-container #overview .files li div
{
  border:1px solid #999;
  float:left;
  margin:.2em .5em 0 0;
  overflow:hidden;
  width:.8em;
  height:.8em;
}

#trac-container #overview div.add div,#trac-container #overview div.cp div,#trac-container #overview div.mv div
{
  border:0;
  margin:0;
  float:right;
  width:.35em;
}

#trac-container #overview .changeset
{
  padding:0 0 1px;
}

#trac-container #overview dd.changeset p
{
  margin-bottom:0;
  margin-top:0;
}

#trac-container #overview .files
{
  padding:1px 0;
}

#trac-container .diff ul.props
{
  font-size:90%;
  list-style:disc;
  margin:.5em 0 0;
  padding:0 .5em 1em 2em;
}

#trac-container .diff ul.props li
{
  margin:0;
  padding:0;
}

#trac-container #title dl
{
  display:inline;
  font-size:110%;
}

#trac-container #title dt
{
  display:inline;
  font-size:110%;
  font-weight:bold;
  margin-left:3em;
}

#trac-container #title dd
{
  display:inline;
  margin-left:.4em;
}