/* This file has been automatically generated by trac-rescope. Do not edit. */
/* Diff preferences */
#trac-container #prefs fieldset
{
  margin:1em .5em .5em;
  padding:.5em 1em 0;
}

/* Diff/change overview */
#trac-container #overview
{
  line-height:130%;
  margin-top:1em;
  padding:.5em;
}

#trac-container #overview dt.property
{
  font-weight:bold;
  padding-right:.25em;
  position:absolute;
  left:0;
  text-align:right;
  width:7.75em;
}

#trac-container #overview dd
{
  margin-left:8em;
}

#trac-container #overview .message
{
  padding:1em 0 1px;
}

#trac-container #overview dd.message p,#trac-container #overview dd.message ul,#trac-container #overview dd.message ol,#trac-container #overview dd.message pre
{
  margin-bottom:1em;
  margin-top:0;
}

/* Colors for change types */
#trac-container .chglist .edit,#trac-container #overview .mod,#trac-container .diff .legend .mod
{
  background:#fd8;
}

#trac-container .chglist .delete,#trac-container #overview .rem,#trac-container .diff .legend .rem
{
  background:#f88;
}

#trac-container .chglist .add,#trac-container #overview .add,#trac-container .diff .legend .add
{
  background:#bfb;
}

#trac-container .chglist .copy,#trac-container #overview .cp,#trac-container .diff .legend .cp
{
  background:#88f;
}

#trac-container .chglist .move,#trac-container #overview .mv,#trac-container .diff .legend .mv
{
  background:#ccc;
}

#trac-container .chglist .unknown
{
  background:#fff;
}

/* Legend for diff and file colors */
#trac-container .legend
{
  font-size:9px;
  line-height:1em;
  padding:.5em 0;
}

#trac-container .legend h3
{
  display:none;
}

#trac-container .legend dt
{
  background:#fff;
  border:1px solid #999;
  float:left;
  margin:.1em .5em .1em 0;
  overflow:hidden;
  width:.8em;
  height:.8em;
}

#trac-container .legend dl
{
  display:inline;
  padding:0;
  margin:0;
  margin-right:.5em;
}

#trac-container .legend dd
{
  display:inline;
  float:left;
  padding:0;
  margin:0;
  margin-right:2em;
}

#trac-container #diff-legend
{
  float:left;
  clear:right;
  margin:1em .5em;
}

#trac-container #file-legend dd
{
  margin-left:0;
}

/* Styles for the list of diffs */
#trac-container .diff ul.entries
{
  clear:both;
  margin:0;
  padding:0;
}

#trac-container .diff li.entry
{
  background:#f7f7f7;
  border:1px solid #d7d7d7;
  list-style-type:none;
  margin:0 0 2em;
  padding:2px;
  position:relative;
  width:100%;
}

#trac-container .diff h2
{
  color:#333;
  font-size:14px;
  letter-spacing:normal;
  margin:0 auto;
  padding:.1em 0 .25em .5em;
}

#trac-container .diff h2 .switch
{
  color:#999;
  float:right;
  font-size:75%;
  line-height:1.6;
}

#trac-container .diff h2 .switch span
{
  border-left:1px solid #ccc;
  cursor:pointer;
  padding:0 1em;
}

#trac-container .diff h2 .switch span:first-child
{
  border:none;
}

#trac-container .diff h2 .switch span.active
{
  color:#333;
  cursor:default;
}

/* Styles for the actual diff tables (side-by-side and inline) */
#trac-container .diff table.trac-diff
{
  border:1px solid #ddd;
  border-spacing:0;
  border-top:0;
  empty-cells:show;
  font-size:12px;
  line-height:130%;
  padding:0;
  margin:0 auto;
  table-layout:fixed;
  width:100%;
}

#trac-container .diff table.trac-diff col.lineno
{
  width:4em;
}

#trac-container .diff table.trac-diff th
{
  border-right:1px solid #d7d7d7;
  border-bottom:1px solid #998;
  font-size:11px;
}

#trac-container .diff table.trac-diff thead th
{
  background:#eee;
  border-top:1px solid #d7d7d7;
  color:#999;
  padding:0 .25em;
  text-align:center;
  white-space:nowrap;
}

#trac-container .diff table.trac-diff tbody th
{
  background:#eed;
  color:#886;
  font-weight:normal;
  padding:0 .5em;
  text-align:right;
  vertical-align:top;
}

#trac-container .diff table.trac-diff td
{
  background:#fff;
  font:normal 11px monospace;
  overflow:visible;
  padding:1px 2px;
  vertical-align:top;
}

#trac-container .diff table.trac-diff tbody.skipped td,#trac-container .diff table.trac-diff thead td
{
  background:#f7f7f7;
  border:1px solid #d7d7d7;
}

#trac-container .diff td ins,#trac-container .diff td del
{
  text-decoration:none;
}

/* Styles for the inline diff */
#trac-container pre.diff .rem
{
  background:#fdd;
}

#trac-container pre.diff .add
{
  background:#dfd;
}

#trac-container .diff table.inline tbody.mod td.l,#trac-container .diff table.inline tbody.rem td.l
{
  background:#fdd;
  border-color:#c00;
  border-style:solid;
  border-width:0 1px 0 1px;
}

#trac-container .diff table.inline tbody.mod td.r,#trac-container .diff table.inline tbody.add td.r
{
  background:#dfd;
  border-color:#0a0;
  border-style:solid;
  border-width:0 1px 0 1px;
}

#trac-container .diff table.inline tbody.mod tr.first td.l,#trac-container .diff table.inline tbody.rem tr.first td.l
{
  border-top-width:1px;
}

#trac-container .diff table.inline tbody.mod tr.last td.l,#trac-container .diff table.inline tbody.rem tr.last td.l
{
  border-bottom-width:1px;
}

#trac-container .diff table.inline tbody.mod tr.first td.r,#trac-container .diff table.inline tbody.add tr.first td.r
{
  border-top-width:1px;
}

#trac-container .diff table.inline tbody.mod tr.last td.r,#trac-container .diff table.inline tbody.add tr.last td.r
{
  border-bottom-width:1px;
}

#trac-container .diff table.inline tbody.mod td del
{
  background:#e99;
  color:#000;
}

#trac-container .diff table.inline tbody.mod td ins
{
  background:#9e9;
  color:#000;
}

/* Styles for the side-by-side diff */
#trac-container .diff table.sidebyside colgroup.content
{
  width:50%;
}

#trac-container .diff table.sidebyside tbody.mod td.l
{
  background:#fe9;
}

#trac-container .diff table.sidebyside tbody.mod td.r
{
  background:#fd8;
}

#trac-container .diff table.sidebyside tbody.add td.l
{
  background:#dfd;
}

#trac-container .diff table.sidebyside tbody.add td.r
{
  background:#cfc;
}

#trac-container .diff table.sidebyside tbody.rem td.l
{
  background:#f88;
}

#trac-container .diff table.sidebyside tbody.rem td.r
{
  background:#faa;
}

#trac-container .diff table.sidebyside tbody.mod del,#trac-container .diff table.sidebyside tbody.mod ins
{
  background:#fc0;
}

/* Styles for the plain-text diff view */
#trac-container .diff pre
{
  background:#fff;
  border:1px solid #ddd;
  font-size:85%;
  margin:0;
}

/* Styles for the property diffs */
#trac-container .diff table.props td
{
  padding:2px .5em;
}