/* This file has been automatically generated by trac-rescope. Do not edit. */
@import url(code.css);
#trac-container #info
{
  margin:0 0 1em 0;
}

#trac-container #wikipage
{
  clear:both;
}

/* Styles for the path of hierarchical pages */
#trac-container #pagepath
{
  font-size:10px;
  /* same as .nav ul in trac.css */
  float:left;
}

#trac-container #pagepath :link,#trac-container #pagepath :visited
{
  margin:0 .2em;
}

#trac-container #pagepath .first:link,#trac-container #pagepath .first:visited
{
  color:#998;
}

#trac-container #pagepath .sep
{
  color:#666;
  padding:0 .1em;
}

#trac-container #pagepath .pathentry
{
  float:left;
}

/* Styles for the page editing form */
#trac-container .preview-right
{
  float:right;
  width:50%;
  display:block;
  margin:0 0 0 1em;
}

#trac-container .sidebyside > h2
{
  margin:.4em 0;
}

#trac-container .sidebyside #preview
{
  margin:0 0 1em 0;
}

#trac-container #edit
{
  margin-top:.5em;
}

#trac-container #edit #rows
{
  float:right;
  font-size:80%;
  margin:.4em 0 0 0;
}

#trac-container #edit #rows select
{
  font-size:90%;
}

#trac-container #edit fieldset
{
  margin-left:1px;
  margin-right:1px;
}

#trac-container #edit #text
{
  clear:both;
  margin-left:-1px;
  margin-right:-1px;
  padding:0;
  width:100%;
  min-height:10em;
  resize:vertical;
}

#trac-container #edit .wikitoolbar
{
  float:left;
  margin-left:-1px;
}

#trac-container #edit div.trac-resizable
{
  clear:both;
  width:100%;
}

#trac-container #changeinfo
{
  padding:.5em;
}

#trac-container #changeinfo .field
{
  float:left;
  margin:0 1em .5em 0;
}

#trac-container #changeinfo
{
  clear:both;
}

#trac-container #changeinfo br
{
  clear:left;
}

#trac-container #changeinfo .options
{
  padding:0 0 1em 1em;
}

#trac-container #changeinfo .options,#trac-container #changeinfo .buttons
{
  clear:left;
}

#trac-container #delete,#trac-container #rename,#trac-container #save
{
  margin-left:3em;
}

#trac-container #preview
{
  background:#f8f8f8 url(../../common/draft.png);
  margin:1em 0 2em;
  overflow:auto;
}

#trac-container #template
{
  vertical-align:middle;
  padding-top:1em;
}

/* Diff view */
#trac-container #overview .multi
{
  color:#999;
}

#trac-container #overview .ipnr
{
  color:#999;
  font-size:80%;
}

#trac-container #overview .comment
{
  padding:1em 0 0;
}

@media print
{
  #trac-container th.diff,#trac-container td.diff
{
    display:none;
  }

}

/* Styles for the TracGuideToc wikimacro */
#trac-container .wiki-toc
{
  padding:.5em 1em;
  margin:0 0 2em 1em;
  float:right;
  clear:right;
  border:1px outset #ddc;
  background:#ffd;
  font-size:85%;
  position:relative;
}

#trac-container .wiki-toc h4
{
  font-size:12px;
  margin:0;
}

#trac-container .wiki-toc ul,#trac-container .wiki-toc ol
{
  list-style:none;
  padding:0;
  margin:0;
}

#trac-container .wiki-toc ul ul,#trac-container .wiki-toc ol ol
{
  padding-left:1.2em;
}

#trac-container .wiki-toc li
{
  margin:0;
  padding:0;
}

#trac-container .wiki-toc .active
{
  background:#ff9;
  position:relative;
}

#trac-container div.trac-modifiedby
{
  margin:.3em .5em;
  color:#888;
  font-size:80%;
  font-style:italic;
  text-align:right;
  float:right;
}

#trac-container div.trac-modifiedby :link,#trac-container div.trac-modifiedby :visited
{
  color:inherit;
}

#trac-container div.trac-modifiedby span.trac-print
{
  display:none;
}

@media print
{
  #trac-container div.trac-modifiedby span
{
    display:none;
  }

  #trac-container div.trac-modifiedby span.trac-print
{
    display:block;
  }

}