/* This file has been automatically generated by trac-rescope. Do not edit. */
#trac-container #prefs
{
  margin-top:-.6em;
}

* html #trac-container #prefs
{
  width:34em;
}

/* Set width only for IE */
#trac-container #prefs fieldset
{
  margin:0;
}

#trac-container #prefs fieldset label
{
  display:block;
}

#trac-container #prefs .buttons
{
  margin-top:-2.3em;
}

#trac-container #prefs .choice
{
  float:left;
  margin:0 .6em 0 .3em;
  border-right:1px dotted #d7d7d7;
}

#trac-container #file-legend
{
  margin-top:3em;
}

/* Browser */
#trac-container h1
{
  margin:0;
  padding:0 0 .5em;
}

#trac-container h1 :link,#trac-container h1 :visited,#trac-container h1 .filename
{
  border:none;
  padding:0 .2em;
}

#trac-container h1 :link,#trac-container h1 :visited
{
  color:#b00;
}

#trac-container h1 .first:link,#trac-container h1 .first:visited
{
  color:#998;
}

#trac-container h1 .sep
{
  color:#666;
  padding:0 .1em;
}

#trac-container h1 .pathentry
{
  float:left;
}

#trac-container #jumprev,#trac-container #jumploc
{
  float:right;
  font-size:10px;
  margin:0 0 .6em;
}

#trac-container #jumprev form,#trac-container #jumploc form
{
  margin:0;
}

#trac-container #jumprev input,#trac-container #jumploc select,#trac-container #jumploc input
{
  font-size:10px;
  margin:0;
}

#trac-container #jumploc div.buttons
{
  margin:0;
}

#trac-container #jumploc
{
  margin-right:2em;
}

/* Browser file annotations */
#trac-container table.code th.blame
{
  width:5em;
}

#trac-container table.code th.blame a
{
  color:#ddd;
}

#trac-container div.message
{
  background:#f7f7f0;
  border:3px double #d7d7d7;
  margin:0;
  padding:8px;
  /* Note: border width and padding must be compensated for in the placement */
}

#trac-container div.message div.inlinebuttons
{
  float:right;
}

/* Styles for the directory entries table
   (extends the styles for "table.listing") */
#trac-container table.dirlist
{
  margin-top:0;
}

#trac-container table.dirlist td.rev,#trac-container table.dirlist td.age,#trac-container table.dirlist td.author,#trac-container table.dirlist td.change
{
  color:#888;
  white-space:nowrap;
  vertical-align:middle;
}

#trac-container table.dirlist td.rev
{
  font-family:monospace;
  letter-spacing:-.08em;
  font-size:90%;
  text-align:right;
}

#trac-container table.dirlist td.size
{
  color:#888;
  white-space:nowrap;
  text-align:right;
  vertical-align:middle;
  font-size:70%;
}

#trac-container table.dirlist td.age
{
  border-width:0 2px 0 0;
  border-style:solid;
  font-size:85%;
}

#trac-container table.dirlist td.name
{
  width:100%;
}

#trac-container table.dirlist td.name a,#trac-container table.dirlist td.name span
{
  background-position:0% 50%;
  background-repeat:no-repeat;
  padding-left:20px;
}

#trac-container table.dirlist td.name a.parent
{
  background-image:url(../../common/parent.png);
}

#trac-container table.dirlist td.name div
{
  white-space:pre;
}

#trac-container table.dirlist tr span.expander
{
  background-image:url(../../common/expander_normal.png);
  cursor:pointer;
  padding-left:8px;
  margin-left:4px;
}

#trac-container table.dirlist tr span.expander:hover
{
  background-image:url(../../common/expander_normal_hover.png);
}

#trac-container table.dirlist tr.expanded span.expander
{
  background-image:url(../../common/expander_open.png);
  padding-left:12px;
  margin-left:0;
}

#trac-container table.dirlist tr.expanded span.expander:hover
{
  background-image:url(../../common/expander_open_hover.png);
}

#trac-container table.dirlist td.name a.dir
{
  background-image:url(../../common/folder.png);
}

#trac-container table.dirlist td.name a.file
{
  background-image:url(../../common/file.png);
  display:block;
}

#trac-container table.dirlist td.name a,#trac-container table.dirlist td.rev a
{
  border-bottom:none;
}

#trac-container table.dirlist td.author,#trac-container table.dirlist td.change
{
  font-size:85%;
}

#trac-container table.dirlist td.rev a.chgset
{
  background-repeat:no-repeat;
  background-image:url(../../common/changeset.png);
  background-position:100% 50%;
  padding:0 0 0 5px;
  margin:0 5px 0 0;
}

#trac-container table.dirlist td.description
{
  padding-left:2em;
}

#trac-container table.dirlist td.description > :first-child
{
  margin-top:0;
}

#trac-container table.dirlist td.description > :last-child
{
  margin-bottom:0;
}

#trac-container table.dirlist td span.loading
{
  background-image:url(../../common/loading.gif);
  font-style:italic;
}

#trac-container #content.browser div.description
{
  padding:0 .5em;
}

/* Style for the ''View Changes'' button and the diff preparation form */
#trac-container #anydiff
{
  margin:0 0 1em;
  float:left;
}

#trac-container #anydiff form,#trac-container #anydiff div,#trac-container #anydiff h2
{
  display:inline;
}

#trac-container #anydiff form th
{
  text-align:right;
}

#trac-container #anydiff input
{
  vertical-align:baseline;
  margin:0 -.5em 0 1em;
}

@media print
{
  #trac-container #anydiff form
{
    display:none;
  }

}

/* Log */
#trac-container tr.diff input
{
  padding:0 1em;
  margin:0;
}

@media print
{
  #trac-container th.diff,#trac-container td.diff
{
    display:none;
  }

}

/* Styles for the revision log table (extends the styles for "table.listing") */
#trac-container table.chglist
{
  margin-top:0;
}

#trac-container .chglist td.diff,#trac-container .chglist td.rev,#trac-container .chglist td.age,#trac-container .chglist td.author,#trac-container .chglist td.change
{
  white-space:nowrap;
  vertical-align:middle;
}

#trac-container .chglist td.author
{
  color:#888;
}

#trac-container .chglist td.change span
{
  border:1px solid #999;
  display:block;
  margin:.2em .5em 0 0;
  width:.8em;
  height:.8em;
}

#trac-container .chglist td.diff
{
  padding:1px;
}

#trac-container .chglist td.change .comment
{
  display:none;
}

#trac-container .chglist td.age
{
  font-size:85%;
}

#trac-container .chglist td.author
{
  font-size:85%;
}

#trac-container .chglist td.rev
{
  font-family:monospace;
  letter-spacing:-.08em;
  font-size:90%;
  text-align:right;
}

#trac-container .chglist td.rev a
{
  border-bottom:none;
}

#trac-container .chglist td.rev a.chgset
{
  background-repeat:no-repeat;
  background-image:url(../../common/changeset.png);
  background-position:100% 50%;
  padding:0 0 0 5px;
  margin:0 5px 0 0;
}

#trac-container .chglist td.summary,#trac-container .chglist td.log
{
  width:100%;
  font-size:85%;
  vertical-align:middle;
}

#trac-container .chglist td.summary *,#trac-container .chglist td.log *
{
  margin-top:0;
}

/* verbose mode */
#trac-container .chglist tr.verbose
{
  border-top:none;
}

#trac-container .chglist tr.verbose td.filler,#trac-container .chglist tr.verbose td.log
{
  border:none;
  border-bottom:1px solid #ddd;
  color:#333;
}

#trac-container .chglist tr.verbose td
{
  border:none;
}

#trac-container .chglist tr.verbose td.diff,#trac-container .chglist tr.verbose td.filler
{
  border-left:1px solid #ddd;
}

#trac-container .chglist tr.verbose td.summary,#trac-container .chglist tr.verbose td.log
{
  border-right:1px solid #ddd;
}

#trac-container #paging
{
  margin:1em 0;
}

/* Styles for the revision info in the file view (see also trac.css) */
#trac-container #info
{
  margin:0;
}

#trac-container #info .props
{
  color:#666;
  list-style:square;
  margin:0 0 .4em 1.6em;
  padding:0;
}

#trac-container #info .props > li
{
  padding:2px 0;
  overflow:auto;
}

#trac-container .trac-toggledeleted
{
  display:none;
  margin-left:3em;
  white-space:nowrap;
}

/* Styles for the HTML preview */
#trac-container #preview
{
  background:#fff;
  clear:both;
  margin:0;
}

#trac-container #preview .code-block
{
  border-top:1px solid #999;
  margin:0;
}

#trac-container #preview .image-file
{
  overflow:hidden;
}

#trac-container #preview .image-file img
{
  max-width:100%;
}