/* This file has been automatically generated by trac-rescope. Do not edit. */
/* General styles for the progress bars */
#trac-container table.progress
{
  border:1px solid #d7d7d7;
  border-collapse:collapse;
  border-spacing:0;
  float:left;
  margin:0;
  padding:0;
  empty-cells:show;
}

#trac-container table.progress a,#trac-container table.progress :link,#trac-container table.progress :visited,#trac-container table.progress :link:hover,#trac-container table.progress :visited:hover
{
  border:none;
  display:block;
  width:100%;
  height:1.2em;
  padding:0;
  margin:0;
  text-decoration:none;
}

#trac-container table.progress td
{
  background:#fff;
  padding:0;
}

#trac-container table.progress td.new
{
  background:#f5f5b5;
}

#trac-container table.progress td.closed
{
  background:#bae0ba;
}

#trac-container table.progress td :hover
{
  background:none;
}

#trac-container p.percent
{
  line-height:1.2em;
  margin:0;
}

/* Styles for the roadmap view */
#trac-container .milestones
{
  margin:2em 0 0;
  padding:0;
}

#trac-container .milestone
{
  margin-bottom:4em;
}

#trac-container .milestone .info
{
  white-space:nowrap;
}

#trac-container .milestone .info h2
{
  background:#f7f7f7;
  border-bottom:1px solid #d7d7d7;
  margin:0;
}

#trac-container .milestone .info h2 :link,#trac-container .milestone .info h2 :visited
{
  color:#000;
  display:block;
  border-bottom:none;
}

#trac-container .milestone .info h2 :link:hover,#trac-container .milestone .info h2 :visited:hover
{
  color:#000;
}

#trac-container .milestone .info h2 em
{
  color:#b00;
  font-style:normal;
}

#trac-container .milestone .info .date
{
  color:#888;
  font-size:11px;
  font-style:italic;
  margin:0 0 1em 0;
}

#trac-container .milestone .info .progress
{
  margin:0 1em;
  width:40em;
  max-width:70%;
}

#trac-container .milestone .info dl
{
  font-size:10px;
  font-style:italic;
  margin:1em 1em 2em;
  white-space:nowrap;
  clear:left;
}

#trac-container .milestone .info dt
{
  display:inline;
  margin-left:.5em;
}

#trac-container .milestone .info dd
{
  display:inline;
  margin:0 1em 0 .5em;
}

#trac-container .milestone .description
{
  margin-left:1em;
}

/* Styles for the milestone view */
#trac-container .milestone .date
{
  color:#888;
  font-style:italic;
  margin:0;
}

#trac-container .milestone .description
{
  margin:1em 0 2em;
}

/* Styles for the milestone statistics table */
#trac-container #stats
{
  float:right;
  margin:0 0 2em 2em;
  width:400px;
  max-width:40%;
}

#trac-container #stats legend
{
  white-space:nowrap;
}

#trac-container #stats table
{
  border-collapse:collapse;
  width:100%;
}

#trac-container #stats th,#trac-container #stats td
{
  font-size:10px;
  padding:0;
  white-space:nowrap;
}

#trac-container #stats th
{
  text-align:right;
}

#trac-container #stats th :link,#trac-container #stats th :visited
{
  border:none;
}

#trac-container #stats td
{
  padding-left:.5em;
  width:100%;
}

#trac-container #stats td table.progress
{
  margin:3px 1em 3px 0;
}

#trac-container #stats td table.progress td
{
  padding:0;
}

#trac-container #stats td p.percent
{
  margin-top:3px;
}

/* Styles for the milestone edit form */
#trac-container #edit fieldset
{
  margin:1em 0;
}

#trac-container #edit em
{
  color:#888;
  font-size:smaller;
}

#trac-container #edit .disabled em
{
  color:#d7d7d7;
}

#trac-container #edit .field
{
  margin:.5em 0;
}

#trac-container #edit label
{
  padding-left:.2em;
}

#trac-container #edit fieldset.iefix
{
  margin-left:1px;
  margin-right:1px;
}

#trac-container #edit textarea#description
{
  margin-left:-1px;
  margin-right:-1px;
  padding:0;
  width:100%;
}

#trac-container #edit .wikitoolbar
{
  margin-left:-1px;
}

#trac-container #edit div.trac-resizable
{
  width:100%;
}