<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">
  <xi:include href="admin.html" />
  <head>
    <title>Communication Settings</title>
  </head>

  <body>
    <div py:if="message" class="status-message">
      $message
    </div>

    <form class="mod" method="get">
      <fieldset>
        <legend>Ticket Notification</legend>
        <div class="field">
          <label for="owner">Always Notify Owner</label>
          <input type="checkbox" name="owner" value="1" checked="$owner" />
        </div>
        <div class="field">
          <label for="owner">Always Notify Reporter</label>
          <input type="checkbox" name="reporter" value="1" checked="$reporter"/>
        </div>
        <div class="field">
          <label for="owner">Always Notify Updater</label>
          <input type="checkbox" name="updater" value="1" checked="$updater"/>
        </div>
        
        <!-- POR -->
        <div class="field">
          <label for="owner">Always Notify CC (comma separated emails)</label>
          <input type="text" name="alwayscc" value="$alwayscc"/>
        </div>
        <div class="field">
          <label for="owner">Always Notify BCC (comma separated emails)</label>
          <input type="text" name="alwaysbcc" value="$alwaysbcc"/>
        </div>

      </fieldset>
      <div class="buttons">
        <input type="submit" name="communication_applied" value="Apply changes"/>
      </div>
    </form>

  </body>
</html>

