/* This file has been automatically generated by trac-rescope. Do not edit. */
#trac-container #content.search .filters
{
  color:#333;
  font-size:85%;
}

#trac-container #content.search form
{
  margin:1em 0 0;
}

#trac-container #content.search form p
{
  margin:.5em 0;
}

#trac-container #content.search hr
{
  clear:left;
  margin-bottom:0;
}

#trac-container #content.search #notfound
{
  margin:2em;
  font-size:110%;
}

#trac-container #content.search #results
{
  margin-right:3em;
}

#trac-container #content.search #results dt
{
  margin:1.5em 0 0;
}

#trac-container #content.search #results dt a
{
  color:#33c;
}

#trac-container #content.search #results dd
{
  font-size:80%;
  margin:0;
  padding:0;
}

#trac-container #content.search #results .author,#trac-container #results .date
{
  color:#090;
}

#trac-container #content.search #quickjump
{
  font-style:italic;
  font-weight:bold;
}