/* This file has been automatically generated by trac-rescope. Do not edit. */
@import url(code.css);
#trac-container #content.ticket
{
  width:58em;
  max-width:100%;
  margin-left:auto;
  margin-right:auto;
}

#trac-container #field-description-help
{
  float:right;
}

#trac-container #properties div.trac-resizable,#trac-container #field-description
{
  width:100%;
}

#trac-container #ticket
{
  background:#ffd;
  border:1px outset #996;
  margin-top:1em;
  padding:.5em 1em;
  position:relative;
}

#trac-container #ticket.ticketdraft
{
  background:#f8f8f8 url(../../common/draft.png);
}

#trac-container #ticketchange.ticketdraft
{
  padding:0 1em;
  margin:1em 0;
}

#trac-container #ticketchange.ticketdraft h3
{
  margin-top:.5em;
}

#trac-container .preview-notice
{
  font-weight:bold;
}

#trac-container .ticketdraft
{
  background:#f8f8f8 url(../../common/draft.png);
  border:1px outset #996;
  padding:0 .2em;
}

#trac-container h1 .status
{
  color:#444;
}

#trac-container #ticket h2.summary
{
  margin:0 0 .8em 0;
}

#trac-container #ticket .date
{
  color:#996;
  float:right;
  font-size:85%;
  position:relative;
}

#trac-container #ticket .date p
{
  margin:.3em;
}

#trac-container #ticket table.properties
{
  clear:both;
  border-top:1px solid #dd9;
  border-collapse:collapse;
  table-layout:fixed;
  width:100%;
}

#trac-container #ticket table.properties tr
{
  border-bottom:1px dotted #eed;
}

#trac-container #ticket table.properties td,#trac-container #ticket table.properties th
{
  font-size:80%;
  padding:.5em 1em;
  vertical-align:top;
}

#trac-container #ticket table.properties th
{
  color:#663;
  font-weight:normal;
  text-align:left;
  width:20%;
}

#trac-container #ticket table.properties td
{
  width:30%;
}

#trac-container #ticket table.properties td p:first-child
{
  margin-top:0;
}

#trac-container #ticket table.properties td p:last-child
{
  margin-bottom:0;
}

#trac-container #ticket table.properties .description
{
  border-top:1px solid #dd9;
}

#trac-container #ticket .description h3
{
  border-bottom:1px solid #dd9;
  color:#663;
  font-size:100%;
  font-weight:normal;
}

#trac-container #ticket .description h3 .lastmod
{
  font-size:90%;
}

#trac-container #ticket .inlinebuttons
{
  float:right;
  position:relative;
  bottom:.3em;
  margin-left:.2em;
}

#trac-container #changelog
{
  border:1px outset #996;
  padding:1em;
}

#trac-container .trac-shade
{
  background-color:#eee;
}

#trac-container #trac-comment-editor
{
  margin-left:2em;
  margin-bottom:1em;
}

#trac-container #trac-comment-editor div.trac-resizable
{
  width:100%;
}

#trac-container #trac-comment-editor textarea
{
  background:#ffffe0;
  margin-left:-1px;
  margin-right:-1px;
  width:100%;
}

#trac-container #trac-comment-editor .wikitoolbar
{
  margin-left:-1px;
}

#trac-container #trac-add-comment :link,#trac-container #trac-add-comment :visited
{
  color:#b00;
}

#trac-container #changelog h3,#trac-container #ticketchange h3
{
  border-bottom:1px solid #d7d7d7;
  color:#999;
  font-size:100%;
  font-weight:normal;
}

#trac-container .threading,#trac-container #changelog .inlinebuttons
{
  float:right;
  margin-left:.2em;
}

#trac-container .threading
{
  font-size:85%;
}

#trac-container .threading :link,#trac-container .threading :visited
{
  border-bottom:0;
}

#trac-container #changelog .trac-lastedit
{
  padding-left:2.5em;
  color:#999;
  font-size:80%;
}

#trac-container #changelog .trac-lastedit :link,#trac-container #changelog .trac-lastedit :visited
{
  color:inherit;
}

#trac-container #changelog .changes,#trac-container #ticketchange .changes
{
  list-style:square;
  margin-left:2em;
  padding:0;
}

#trac-container #changelog .comment,#trac-container #ticketchange .comment
{
  margin-left:2em;
}

#trac-container form .field
{
  margin-top:.75em;
  width:100%;
}

#trac-container form .field fieldset.iefix
{
  margin-left:1px;
  margin-right:1px;
}

#trac-container label[for=comment]
{
  float:right;
}

#trac-container #comment
{
  margin-left:-1px;
  margin-right:-1px;
  padding:0;
  width:100%;
}

#trac-container form .field .wikitoolbar
{
  margin-left:-1px;
}

#trac-container form .field div.trac-resizable
{
  width:100%;
}

#trac-container #properties
{
  white-space:nowrap;
  line-height:160%;
  padding:.5em;
}

#trac-container #properties table
{
  border-spacing:0;
  width:100%;
  padding:0 .5em;
}

#trac-container #properties table th
{
  padding:.4em;
  text-align:right;
  width:20%;
  vertical-align:top;
}

#trac-container #properties table th.col2
{
  border-left:1px dotted #d7d7d7;
}

#trac-container #properties table td
{
  vertical-align:middle;
  width:30%;
}

#trac-container #properties table td.fullrow
{
  vertical-align:middle;
  width:80%;
}

#trac-container #action
{
  line-height:2em;
}

#trac-container fieldset.radio
{
  border:none;
  margin:0;
  padding:0;
}

#trac-container fieldset.radio legend
{
  color:#000;
  float:left;
  font-size:100%;
  font-weight:normal;
  padding:0 1em 0 0;
}

#trac-container fieldset.radio label
{
  padding-right:1em;
}