/* This file has been automatically generated by trac-rescope. Do not edit. */
#trac-container div.code
{
  background:#f7f7f7;
  border:1px solid #d7d7d7;
  margin:1em 1.75em;
  padding:.25em;
  overflow:auto;
}

#trac-container div.code pre
{
  margin:0;
}

#trac-container table.code
{
  border:1px solid #ddd;
  border-spacing:0;
  border-top:0;
  border-collapse:collapse;
  empty-cells:show;
  font-size:12px;
  line-height:130%;
  padding:0;
  margin:0 auto;
  table-layout:fixed;
  width:100%;
}

#trac-container table.code th
{
  border-right:1px solid #d7d7d7;
  border-bottom:1px solid #998;
  font-size:11px;
}

#trac-container table.code th.lineno
{
  width:4em;
}

#trac-container table.code thead th
{
  background:#eee;
  border-top:1px solid #d7d7d7;
  color:#999;
  padding:0 .25em;
  text-align:center;
  white-space:nowrap;
}

#trac-container table.code thead th.content
{
  text-align:left;
}

#trac-container table.code thead th.content span.recover
{
  background:#f7f7f7;
  border-left:1px solid;
  border-right:1px solid;
  cursor:pointer;
  margin:0 1em 0 0;
  padding:0 .5em;
}

#trac-container table.code tbody th
{
  background:#eed;
  color:#886;
  font-weight:normal;
  padding:0 .5em;
  text-align:right;
  vertical-align:top;
}

#trac-container table.code tbody th :link,#trac-container table.code tbody th :visited
{
  border:none;
  color:#886;
  text-decoration:none;
}

#trac-container table.code tbody th :link:hover,#trac-container table.code tbody th :visited:hover
{
  color:#000;
}

#trac-container table.code td
{
  font:normal 11px monospace;
  overflow:hidden;
  padding:1px 2px;
  vertical-align:top;
}

#trac-container table.code tr.hilite th
{
  background:#ccf;
}

#trac-container table.code tr.hilite td
{
  background:#ddf;
}

#trac-container .image-file
{
  background:#eee;
  padding:.3em;
}

#trac-container .image-file img
{
  background:url(../../common/imggrid.png);
}

/* Default */
#trac-container .code-block span
{
  font-family:monospace;
}

/* Comments */
#trac-container .code-comment,#trac-container .css_comment,#trac-container .c_comment,#trac-container .c_commentdoc,#trac-container .c_commentline,#trac-container .c_commentlinedoc,#trac-container .h_comment,#trac-container .pl_commentline,#trac-container .p_commentblock,#trac-container .p_commentline,#trac-container .hphp_comment,#trac-container .hphp_commentblock,#trac-container .hphp_commentline,#trac-container .yaml_comment
{
  color:#998;
  font-style:italic;
}

/* Language keyword */
#trac-container .code-keyword,#trac-container .pl_word
{
  color:#789;
  font-weight:bold;
}

/* Type */
#trac-container .code-type,#trac-container .c_word,#trac-container .c_word2,#trac-container .p_classname,#trac-container .hphp_classname
{
  color:#468;
  font-weight:bold;
}

/* Function */
#trac-container .code-func,#trac-container .p_defname
{
  color:#900;
  font-weight:bold;
  border-bottom:none;
}

/* Pre-processor */
#trac-container .code-prep,#trac-container .c_preprocessor,#trac-container .pl_preprocessor,#trac-container .yaml_identifier
{
  color:#999;
  font-weight:bold;
}

/* Language construct */
#trac-container .code-lang,#trac-container .p_word
{
  color:#000;
  font-weight:bold;
}

/* String */
#trac-container .code-string,#trac-container .c_string,#trac-container .c_stringeol,#trac-container .css_doublestring,#trac-container .css_singlestring,#trac-container .h_singlestring,#trac-container .h_doublestring,#trac-container .pl_string,#trac-container .pl_string_q,#trac-container .pl_string_qq,#trac-container .pl_string_qr,#trac-container .pl_string_qw,#trac-container .pl_string_qx,#trac-container .pl_backticks,#trac-container .pl_character,#trac-container .p_string,#trac-container .p_stringeol,#trac-container .hphp_string,#trac-container .hphp_stringeol,#trac-container .hphp_triple,#trac-container .hphp_tripledouble,#trac-container .p_character,#trac-container .p_triple,#trac-container .p_tripledouble
{
  color:#b84;
  font-weight:normal;
}

/* Variable name */
#trac-container .code-var
{
  color:#f9f;
}

/* SilverCity-specific styles */
#trac-container .css_id,#trac-container .css_class,#trac-container .css_pseudoclass,#trac-container .css_tag
{
  color:#900000;
}

#trac-container .css_directive
{
  color:#009000;
  font-weight:bold;
}

#trac-container .css_important
{
  color:blue;
}

#trac-container .css_operator
{
  color:#000090;
  font-weight:bold;
}

#trac-container .css_tag
{
  font-weight:bold;
}

#trac-container .css_unknown_identifier,#trac-container .css_unknown_pseudoclass
{
  color:red;
}

#trac-container .css_value
{
  color:navy;
}

#trac-container .c_commentdockeyword
{
  color:navy;
  font-weight:bold;
}

#trac-container .c_commentdockeyworderror
{
  color:red;
  font-weight:bold;
}

#trac-container .c_character,#trac-container .c_regex,#trac-container .c_uuid,#trac-container .c_verbatim
{
  color:olive;
}

#trac-container .c_number
{
  color:#099;
}

#trac-container .h_asp
{
  color:#ff0;
}

#trac-container .h_aspat
{
  color:#ffdf00;
}

#trac-container .h_attribute
{
  color:teal;
}

#trac-container .h_attributeunknown
{
  color:red;
}

#trac-container .h_cdata
{
  color:#373;
}

#trac-container .h_entity
{
  color:purple;
}

#trac-container .h_number
{
  color:#099;
}

#trac-container .h_other
{
  color:purple;
}

#trac-container .h_script,#trac-container .h_tag,#trac-container .h_tagend
{
  color:navy;
}

#trac-container .h_tagunknown
{
  color:red;
}

#trac-container .h_xmlend,#trac-container .h_xmlstart
{
  color:blue;
}

#trac-container .pl_datasection
{
  color:olive;
}

#trac-container .pl_error
{
  color:red;
  font-weight:bold;
}

#trac-container .pl_hash
{
  color:#000;
}

#trac-container .pl_here_delim,#trac-container .pl_here_q,#trac-container .pl_here_qq,#trac-container .pl_here_qx,#trac-container .pl_longquote
{
  color:olive;
}

#trac-container .pl_number
{
  color:#099;
}

#trac-container .pl_pod
{
  font-style:italic;
}

#trac-container .pl_regex,#trac-container .pl_regsubst
{
  color:olive;
}

#trac-container .p_number
{
  color:#099;
}

#trac-container .hphp_character
{
  color:olive;
}

#trac-container .hphp_defname
{
  color:#099;
  font-weight:bold;
}

#trac-container .hphp_number
{
  color:#099;
}

#trac-container .hphp_word
{
  color:navy;
  font-weight:bold;
}

#trac-container .yaml_document
{
  color:gray;
  font-style:italic;
}

#trac-container .yaml_keyword
{
  color:#808;
}

#trac-container .yaml_number
{
  color:#800;
}

#trac-container .yaml_reference
{
  color:#088;
}

#trac-container .v_comment
{
  color:gray;
  font-style:italic;
}

#trac-container .v_commentline,#trac-container .v_commentlinebang
{
  color:red;
  font-style:italic;
}

#trac-container .v_number,#trac-container .v_preprocessor
{
  color:#099;
}

#trac-container .v_string,#trac-container .v_stringeol
{
  color:olive;
}

#trac-container .v_user
{
  color:blue;
  font-weight:bold;
}

#trac-container .v_word,#trac-container .v_word3
{
  color:navy;
  font-weight:bold;
}

#trac-container .v_word2
{
  color:green;
  font-weight:bold;
}