/* This file has been automatically generated by trac-rescope. Do not edit. */
/* Timeline */
* html #trac-container #prefs
{
  width:34em;
}

/* Set width only for IE */
#trac-container #prefs fieldset label
{
  display:block;
}

#trac-container #prefs .buttons
{
  margin-top:-1.6em;
}

#trac-container h2
{
  background:#f7f7f7;
  border-bottom:1px solid #d7d7d7;
  font-size:105%;
  margin:2em 0 .5em;
}

#trac-container dl
{
  line-height:1.3em;
  margin-left:1em;
}

#trac-container dt
{
  background:3px 4px no-repeat;
  padding:0;
}

#trac-container dt :link,#trac-container dt :visited
{
  background:3px 3px no-repeat;
  border:none;
  color:#000;
  padding:0 4px 2px 22px;
}

#trac-container dt > :link,#trac-container dt > :visited
{
  /* Hide from IE/Win */
  background-position:3px 4px;
}

#trac-container dt :link:hover,#trac-container dt :visited:hover
{
  background-color:#eed;
  color:#000;
}

#trac-container dt em
{
  border-bottom:1px dotted #bbb;
  color:#b00;
  font-style:normal;
  text-decoration:none;
}

#trac-container dt .time
{
  color:#999;
  font-size:80%;
}

#trac-container dt .author
{
  color:#666;
}

#trac-container dt.highlight
{
  background-color:#ffa;
}

#trac-container dd
{
  font-size:80%;
  margin:0 0 .75em 5.5em;
  padding:0;
  color:#776;
}

/* Apply icon background-image twice to avoid hover-flicker in IE/Win */
#trac-container dt.changeset,#trac-container dt.changeset a
{
  background-image:url(../../common/changeset.png) !important;
}

#trac-container dt.newticket,#trac-container dt.newticket a
{
  background-image:url(../../common/newticket.png) !important;
}

#trac-container dt.reopenedticket,#trac-container dt.reopenedticket a
{
  background-image:url(../../common/newticket.png) !important;
}

#trac-container dt.editedticket,#trac-container dt.editedticket a
{
  background-image:url(../../common/editedticket.png) !important;
}

#trac-container dt.closedticket,#trac-container dt.closedticket a
{
  background-image:url(../../common/closedticket.png) !important;
}

#trac-container dt.wiki,#trac-container dt.wiki a
{
  background-image:url(../../common/wiki.png) !important;
}

#trac-container dt.milestone,#trac-container dt.milestone a
{
  background-image:url(../../common/milestone.png) !important;
}

#trac-container dt.attachment,#trac-container dt.attachment a
{
  background-image:url(../../common/attachment.png) !important;
}

/* styles for the 'changeset_long_messages' option */
#trac-container dd.changeset p
{
  margin:0;
  padding:0;
}

#trac-container dd.changeset ul
{
  padding-left:15px;
}

/* Styles for the 'changeset_show_files' option */
#trac-container dd.changeset .changes
{
  color:#aaa;
  font-size:90%;
}

#trac-container dd.changeset ul.changes
{
  padding-left:0;
  list-style-type:none;
}

#trac-container dd.changeset .changes li div
{
  border:1px solid #999;
  float:left;
  margin:.5em .5em 0 0;
  overflow:hidden;
  width:.8em;
  height:.8em;
}

#trac-container dd.changeset .changes li span
{
  float:left;
  margin-right:.8em;
}

#trac-container dd.changeset .changes .add
{
  background:#bfb;
}

#trac-container dd.changeset .changes .delete
{
  background:#f88;
}

#trac-container dd.changeset .changes .edit
{
  background:#fd8;
}

#trac-container dd.changeset .changes .copy
{
  background:#88f;
}

#trac-container dd.changeset .changes .move
{
  background:#ccc;
}

#trac-container dd.changeset .branch
{
  font-size:85%;
  background:#f6f6f6;
  border:1px solid #ddd;
  margin:0 .5em 0 0;
  padding:0 .2em;
  float:left;
}

#trac-container dd.changeset .head
{
  background:#d0ffd0;
  border:1px solid #9d9;
}