/* This file has been automatically generated by trac-rescope. Do not edit. */
body #trac-container
{
  background:#fff;
  color:#000;
  margin:10px;
  padding:0;
}

body #trac-container,#trac-container th,#trac-container tr
{
  font-family: Verdana, Arial, 'Bitstream Vera Sans', Helvetica, sans-serif;
  font-size: 13px;
}

#trac-container h1,#trac-container h2,#trac-container h3,#trac-container h4
{
  font-family:Arial,Verdana,"Bitstream Vera Sans",Helvetica,sans-serif;
  font-weight:bold;
  letter-spacing:-.018em;
  page-break-after:avoid;
}

#trac-container h1
{
  font-size:19px;
  margin:.15em 1em .5em 0;
}

#trac-container h2
{
  font-size:16px;
}

#trac-container h3
{
  font-size:14px;
}

#trac-container hr
{
  border:none;
  border-top:1px solid #ccb;
  margin:2em 0;
}

#trac-container address
{
  font-style:normal;
}

#trac-container img
{
  border:none;
}

#trac-container .underline
{
  text-decoration:underline;
}

#trac-container ol.loweralpha
{
  list-style-type:lower-alpha;
}

#trac-container ol.upperalpha
{
  list-style-type:upper-alpha;
}

#trac-container ol.lowerroman
{
  list-style-type:lower-roman;
}

#trac-container ol.upperroman
{
  list-style-type:upper-roman;
}

#trac-container ol.arabic
{
  list-style-type:decimal;
}

/* Link styles */
#trac-container :link,#trac-container :visited
{
  text-decoration:none;
  color:#b00;
  border-bottom:1px dotted #bbb;
}

#trac-container :link:hover,#trac-container :visited:hover
{
  background-color:#eee;
  color:#555;
}

#trac-container h1 :link,#trac-container h1 :visited,#trac-container h2 :link,#trac-container h2 :visited,#trac-container h3 :link,#trac-container h3 :visited,#trac-container h4 :link,#trac-container h4 :visited,#trac-container h5 :link,#trac-container h5 :visited,#trac-container h6 :link,#trac-container h6 :visited
{
  color:inherit;
}

/* Heading anchors */
#trac-container .anchor:link,#trac-container .anchor:visited
{
  border:none;
  color:#d7d7d7;
  font-size:.8em;
  vertical-align:text-top;
}

#trac-container * > .anchor:link,#trac-container * > .anchor:visited
{
  visibility:hidden;
}

#trac-container h1:hover .anchor,#trac-container h2:hover .anchor,#trac-container h3:hover .anchor,#trac-container h4:hover .anchor,#trac-container h5:hover .anchor,#trac-container h6:hover .anchor,#trac-container span:hover .anchor
{
  visibility:visible;
}

@media screen
{
  #trac-container a.ext-link .icon
{
    background:url(../../common/extlink.gif) left center no-repeat;
    padding-left:15px;
  }

  #trac-container a.mail-link .icon
{
    background:url(../../common/envelope.png) left center no-repeat;
    padding-left:16px;
  }

  #trac-container a.trac-rawlink
{
    background:url(../../common/download.png) right center no-repeat;
    padding-right:16px;
    border-bottom:none;
  }

}

/* Forms */
#trac-container input,#trac-container textarea,#trac-container select
{
  margin:2px;
}

#trac-container input,#trac-container select
{
  vertical-align:middle;
}

#trac-container input[type=button],#trac-container input[type=submit],#trac-container input[type=reset]
{
  background:#eee;
  color:#222;
  border:1px outset #ccc;
  padding:.1em .5em;
}

#trac-container input[type=button]:hover,#trac-container input[type=submit]:hover,#trac-container input[type=reset]:hover
{
  background:#ccb;
}

#trac-container input[type=button][disabled],#trac-container input[type=submit][disabled],#trac-container input[type=reset][disabled]
{
  background:#f6f6f6;
  border-style:solid;
  color:#999;
}

#trac-container input[type=text],#trac-container input.textwidget,#trac-container textarea
{
  border:1px solid #d7d7d7;
}

#trac-container input[type=text],#trac-container input.textwidget
{
  padding:.25em .5em;
}

#trac-container input[type=text]:focus,#trac-container input.textwidget:focus,#trac-container textarea:focus
{
  border:1px solid #886;
}

#trac-container option
{
  border-bottom:1px dotted #d7d7d7;
}

#trac-container fieldset
{
  border:1px solid #d7d7d7;
  padding:.5em;
  margin:1em 0;
}

#trac-container p.hint,#trac-container span.hint
{
  color:#666;
  font-size:85%;
  font-style:italic;
  margin:.5em 0;
  padding-left:1em;
}

#trac-container fieldset.iefix
{
  background:transparent;
  border:none;
  padding:0;
  margin:0;
}

* html #trac-container fieldset.iefix
{
  width:98%;
}

#trac-container fieldset.iefix p
{
  margin:0;
}

#trac-container legend
{
  color:#999;
  padding:0 .25em;
  font-size:90%;
  font-weight:bold;
}

#trac-container label.disabled
{
  color:#d7d7d7;
}

#trac-container .buttons
{
  margin:.5em .5em .5em 0;
}

#trac-container .buttons form,#trac-container .buttons form div
{
  display:inline;
}

#trac-container .buttons input
{
  margin:1em .5em .1em 0;
}

#trac-container .inlinebuttons input
{
  font-size:70%;
  border-width:1px;
  border-style:dotted;
  margin:0 .1em;
  padding:.1em;
  background:none;
}

/* Header */
#trac-container #header hr
{
  display:none;
}

#trac-container #header h1
{
  margin:1.5em 0 -1.5em;
  padding:0;
}

#trac-container #header img
{
  border:none;
  margin:0 0 -3em;
}

#trac-container #header :link,#trac-container #header :visited,#trac-container #header :link:hover,#trac-container #header :visited:hover
{
  background:transparent;
  color:#555;
  margin-bottom:2px;
  border:none;
  padding:0;
}

#trac-container #header h1 :link:hover,#trac-container #header h1 :visited:hover
{
  color:#000;
}

/* Quick search */
#trac-container #search
{
  clear:both;
  font-size:10px;
  height:2.2em;
  margin:0 0 1em;
  text-align:right;
}

#trac-container #search input
{
  font-size:10px;
}

#trac-container #search label
{
  display:none;
}

/* Navigation */
#trac-container .nav h2,#trac-container .nav hr
{
  display:none;
}

#trac-container .nav ul
{
  font-size:10px;
  list-style:none;
  margin:0;
  text-align:right;
}

#trac-container .nav li
{
  border-right:1px solid #d7d7d7;
  display:inline;
  padding:0 .75em;
  white-space:nowrap;
}

#trac-container .nav li.last
{
  border-right:none;
}

/* Main navigation bar */
#trac-container #mainnav
{
  background:#fff url(../../common/topbar_gradient.png) 0 0;
  border:1px solid #000;
  font:normal 10px verdana,"Bitstream Vera Sans",helvetica,arial,sans-serif;
  margin:.66em 0 .33em;
  padding:.2em 0;
}

#trac-container #mainnav li
{
  border-right:none;
  padding:.25em 0;
}

#trac-container #mainnav :link,#trac-container #mainnav :visited
{
  background:url(../../common/dots.gif) 0 0 no-repeat;
  border-right:1px solid #fff;
  border-bottom:none;
  border-left:1px solid #555;
  color:#000;
  padding:.2em 20px;
}

* html #trac-container #mainnav :link,* html #trac-container #mainnav :visited
{
  background-position:1px 0;
}

#trac-container #mainnav :link:hover,#trac-container #mainnav :visited:hover
{
  background-color:#ccc;
  border-right:1px solid #ddd;
}

#trac-container #mainnav .active :link,#trac-container #mainnav .active :visited
{
  background:#000 url(../../common/topbar_gradient2.png) 0 0 repeat-x;
  border-top:none;
  border-right:1px solid #000;
  color:#eee;
  font-weight:bold;
}

#trac-container #mainnav .active :link:hover,#trac-container #mainnav .active :visited:hover
{
  border-right:1px solid #000;
}

/* Context-dependent navigation links */
#trac-container #ctxtnav
{
  min-height:1em;
}

#trac-container #ctxtnav li ul
{
  background:#f7f7f7;
  color:#ccc;
  border:1px solid;
  padding:0;
  display:inline;
  margin:0;
}

#trac-container #ctxtnav li li
{
  padding:0;
}

#trac-container #ctxtnav li li :link,#trac-container #ctxtnav li li :visited
{
  padding:0 1em;
}

#trac-container #ctxtnav li li :link:hover,#trac-container #ctxtnav li li :visited:hover
{
  background:#bba;
  color:#fff;
}

#trac-container .trac-nav,#trac-container .trac-topnav
{
  float:right;
  font-size:80%;
}

#trac-container .trac-topnav
{
  margin-top:14px;
}

/* Alternate links */
#trac-container #altlinks
{
  clear:both;
  text-align:center;
}

#trac-container #altlinks h3
{
  font-size:12px;
  letter-spacing:normal;
  margin:0;
}

#trac-container #altlinks ul
{
  list-style:none;
  margin:0;
  padding:0 0 1em;
}

#trac-container #altlinks li
{
  border-right:1px solid #d7d7d7;
  display:inline;
  font-size:11px;
  line-height:1.5;
  padding:0 1em;
  white-space:nowrap;
}

#trac-container #altlinks li.last
{
  border-right:none;
}

#trac-container #altlinks li :link,#trac-container #altlinks li :visited
{
  background-repeat:no-repeat;
  color:#666;
  border:none;
  padding:0 0 2px;
}

#trac-container #altlinks li a.ics
{
  background:url(../../common/ics.png) left center no-repeat;
  padding-left:22px;
}

#trac-container #altlinks li a.rss
{
  background:url(../../common/feed.png) left center no-repeat;
  padding-left:20px;
}

/* Footer */
#trac-container #footer
{
  clear:both;
  color:#bbb;
  font-size:10px;
  border-top:1px solid;
  height:31px;
  padding:.25em 0;
}

#trac-container #footer :link,#trac-container #footer :visited
{
  color:#bbb;
}

#trac-container #footer hr
{
  display:none;
}

#trac-container #footer #tracpowered
{
  border:0;
  float:left;
}

#trac-container #footer #tracpowered:hover
{
  background:transparent;
}

#trac-container #footer p
{
  margin:0;
}

#trac-container #footer p.left
{
  float:left;
  margin-left:1em;
  padding:0 1em;
  border-left:1px solid #d7d7d7;
  border-right:1px solid #d7d7d7;
}

#trac-container #footer p.right
{
  float:right;
  text-align:right;
}

#trac-container #content
{
  padding-bottom:2em;
  position:relative;
}

#trac-container #help
{
  clear:both;
  color:#999;
  font-size:90%;
  margin:1em;
  text-align:right;
}

#trac-container #help :link,#trac-container #help :visited
{
  cursor:help;
}

#trac-container #help hr
{
  display:none;
}

/* Section folding */
#trac-container .foldable :link,#trac-container .foldable :visited
{
  background:url(../../common/expanded.png) 0 50% no-repeat;
  border:none;
  padding-left:16px;
}

#trac-container .foldable :link:hover,#trac-container .foldable :visited:hover
{
  background-color:transparent;
}

#trac-container .collapsed > .foldable :link,#trac-container .collapsed > .foldable :visited
{
  background-image:url(../../common/collapsed.png);
}

#trac-container .collapsed > div,#trac-container .collapsed > table,#trac-container .collapsed > ul,#trac-container .collapsed > dl
{
  display:none;
}

#trac-container fieldset > legend.foldable :link,#trac-container fieldset > legend.foldable :visited
{
  color:#666;
  font-size:110%;
}

/* Page preferences form */
#trac-container #prefs
{
  background:#f7f7f0;
  border:1px outset #998;
  float:right;
  font-size:9px;
  padding:.8em;
  position:relative;
  margin:0 1em 1em;
}

* html #trac-container #prefs
{
  width:26em;
}

/* Set width only for IE */
#trac-container #prefs input,#trac-container #prefs select
{
  font-size:9px;
  vertical-align:middle;
}

#trac-container #prefs fieldset
{
  background:transparent;
  border:none;
  margin:.5em;
  padding:0;
}

#trac-container #prefs fieldset legend
{
  background:transparent;
  color:#000;
  font-size:9px;
  font-weight:normal;
  margin:0 0 0 -1.5em;
  padding:0;
}

#trac-container #prefs .buttons
{
  text-align:right;
}

/* Version information (browser, wiki, attachments) */
#trac-container #info
{
  margin:1em 0 0 0;
  background:#f7f7f0;
  border:1px solid #d7d7d7;
  border-collapse:collapse;
  border-spacing:0;
  clear:both;
  width:100%;
}

#trac-container #info th,#trac-container #info td
{
  font-size:85%;
  padding:2px .5em;
  vertical-align:top;
}

#trac-container #info th
{
  font-weight:bold;
  text-align:left;
  white-space:nowrap;
}

#trac-container #info td.message
{
  width:100%;
}

#trac-container #info .message ul
{
  padding:0;
  margin:0 2em;
}

#trac-container #info .message p
{
  margin:0;
  padding:0;
}

/* Wiki */
#trac-container .wikipage
{
  padding-left:18px;
}

#trac-container .wikipage h1,#trac-container .wikipage h2,#trac-container .wikipage h3
{
  margin-left:-18px;
}

#trac-container .wikipage table h1,#trac-container .wikipage table h2,#trac-container .wikipage table h3
{
  margin-left:0;
}

#trac-container div.compact > p:first-child
{
  margin-top:0;
}

#trac-container div.compact > p:last-child
{
  margin-bottom:0;
}

#trac-container a.missing:link,#trac-container a.missing:visited,#trac-container a.missing,#trac-container span.missing,#trac-container a.forbidden,#trac-container span.forbidden
{
  color:#998;
}

#trac-container a.missing:hover
{
  color:#000;
}

#trac-container a.closed:link,#trac-container a.closed:visited,#trac-container span.closed
{
  text-decoration:line-through;
}

/* User-selectable styles for blocks */
#trac-container .important
{
  background:#fcb;
  border:1px dotted #d00;
  color:#500;
  padding:0 .5em 0 .5em;
  margin:.5em;
}

#trac-container dl.wiki dt
{
  font-weight:bold;
}

#trac-container dl.compact dt
{
  float:left;
  padding-right:.5em;
}

#trac-container dl.compact dd
{
  margin:0;
  padding:0;
}

#trac-container pre.wiki,#trac-container pre.literal-block
{
  background:#f7f7f7;
  border:1px solid #d7d7d7;
  margin:1em 1.75em;
  padding:.25em;
  overflow:auto;
}

#trac-container blockquote.citation
{
  margin:-.6em 0;
  border-style:solid;
  border-width:0 0 0 2px;
  padding-left:.5em;
  border-color:#b44;
}

#trac-container .citation blockquote.citation
{
  border-color:#4b4;
}

#trac-container .citation .citation blockquote.citation
{
  border-color:#44b;
}

#trac-container .citation .citation .citation blockquote.citation
{
  border-color:#c55;
}

#trac-container table.wiki
{
  border:1px solid #ccc;
  border-collapse:collapse;
  border-spacing:0;
}

#trac-container table.wiki td
{
  border:1px solid #ccc;
  padding:.1em .25em;
}

#trac-container table.wiki th
{
  border:1px solid #bbb;
  padding:.1em .25em;
  background-color:#f7f7f7;
}

#trac-container .wikitoolbar
{
  margin-top:.3em;
  margin-left:2px;
  border:solid #d7d7d7;
  border-width:1px 1px 1px 0;
  height:18px;
  width:234px;
}

#trac-container .wikitoolbar :link,#trac-container .wikitoolbar :visited
{
  background:transparent url(../../common/edit_toolbar.png) no-repeat;
  border:1px solid #fff;
  border-left-color:#d7d7d7;
  cursor:default;
  display:block;
  float:left;
  width:24px;
  height:16px;
}

#trac-container .wikitoolbar :link:hover,#trac-container .wikitoolbar :visited:hover
{
  background-color:transparent;
  border:1px solid #fb2;
}

#trac-container .wikitoolbar a#em
{
  background-position:0 0;
}

#trac-container .wikitoolbar a#strong
{
  background-position:0 -16px;
}

#trac-container .wikitoolbar a#heading
{
  background-position:0 -32px;
}

#trac-container .wikitoolbar a#link
{
  background-position:0 -48px;
}

#trac-container .wikitoolbar a#code
{
  background-position:0 -64px;
}

#trac-container .wikitoolbar a#hr
{
  background-position:0 -80px;
}

#trac-container .wikitoolbar a#np
{
  background-position:0 -96px;
}

#trac-container .wikitoolbar a#br
{
  background-position:0 -112px;
}

#trac-container .wikitoolbar a#img
{
  background-position:0 -128px;
}

/* Textarea resizer */
#trac-container div.trac-resizable
{
  display:table;
  width:1px;
}

#trac-container div.trac-resizable > div
{
  display:table-cell;
}

#trac-container div.trac-resizable textarea
{
  display:block;
  margin-bottom:0;
}

#trac-container div.trac-grip
{
  height:5px;
  overflow:hidden;
  background:#eee url(../../common/grip.png) no-repeat center 1px;
  border:1px solid #ddd;
  border-top-width:0;
  cursor:s-resize;
}

/* Styles for the form for adding attachments. */
#trac-container #attachment .field
{
  margin-top:1.3em;
}

#trac-container #attachment label
{
  padding-left:.2em;
}

#trac-container #attachment fieldset
{
  margin-top:2em;
}

#trac-container #attachment fieldset .field
{
  float:left;
  margin:0 1em .5em 0;
}

#trac-container #attachment .options
{
  float:left;
  padding:0 0 1em 1em;
}

#trac-container #attachment br
{
  clear:left;
}

#trac-container .attachment #preview
{
  margin-top:1em;
}

/* Styles for the list of attachments. */
#trac-container #attachments > div
{
  border:1px outset #996;
  padding:1em;
}

#trac-container #attachments .attachments
{
  margin-left:2em;
  padding:0;
}

#trac-container #attachments dt
{
  display:list-item;
  list-style:square;
}

#trac-container #attachments dd
{
  font-style:italic;
  margin-left:0;
  padding-left:0;
}

/* Styles for tabular listings such as those used for displaying directory
   contents and report results. */
#trac-container table.listing
{
  clear:both;
  border-bottom:1px solid #d7d7d7;
  border-collapse:collapse;
  border-spacing:0;
  margin-top:1em;
  width:100%;
}

#trac-container table.listing th
{
  text-align:left;
  padding:0 1em .1em 0;
  font-size:12px;
}

#trac-container table.listing thead tr
{
  background:#f7f7f0;
}

#trac-container table.listing thead th
{
  border:1px solid #d7d7d7;
  border-bottom-color:#999;
  font-size:11px;
  font-weight:bold;
  padding:2px .5em;
  vertical-align:bottom;
  white-space:nowrap;
}

#trac-container table.listing thead th :link:hover,#trac-container table.listing thead th :visited:hover
{
  background-color:transparent;
}

#trac-container table.listing thead th a
{
  border:none;
  padding-right:12px;
}

#trac-container table.listing th.asc a,#trac-container table.listing th.desc a
{
  font-weight:bold;
  background-position:100% 50%;
  background-repeat:no-repeat;
}

#trac-container table.listing th.asc a
{
  background-image:url(../../common/asc.png);
}

#trac-container table.listing th.desc a
{
  background-image:url(../../common/desc.png);
}

#trac-container table.listing tbody td,#trac-container table.listing tbody th
{
  border:1px dotted #ddd;
  padding:.3em .5em;
  vertical-align:top;
}

#trac-container table.listing tbody td a:hover,#trac-container table.listing tbody th a:hover
{
  background-color:transparent;
}

#trac-container table.listing tbody tr
{
  border-top:1px solid #ddd;
}

#trac-container table.listing tbody tr.even
{
  background-color:#fcfcfc;
}

#trac-container table.listing tbody tr.odd
{
  background-color:#f7f7f7;
}

#trac-container table.listing tbody tr:hover
{
  background:#eed !important;
}

#trac-container table.listing tbody tr.focus
{
  background:#ddf !important;
}

/* Styles for the page history table
   (extends the styles for "table.listing") */
#trac-container #fieldhist td
{
  padding:0 .5em;
}

#trac-container #fieldhist td.date,#trac-container #fieldhist td.diff,#trac-container #fieldhist td.version,#trac-container #fieldhist td.author
{
  white-space:nowrap;
}

#trac-container #fieldhist td.version
{
  text-align:center;
}

#trac-container #fieldhist td.comment
{
  width:100%;
}

/* Auto-completion interface */
#trac-container .suggestions
{
  background:#fff;
  border:1px solid #886;
  color:#222;
}

#trac-container .suggestions ul
{
  font-family:sans-serif;
  max-height:20em;
  min-height:3em;
  list-style:none;
  margin:0;
  overflow:auto;
  padding:0;
  width:440px;
}

* html #trac-container .suggestions ul
{
  height:10em;
}

#trac-container .suggestions li
{
  background:#fff;
  cursor:pointer;
  padding:2px 5px;
}

#trac-container .suggestions li.selected
{
  background:#b9b9b9;
}

/* Styles for the error page (and rst errors) */
#trac-container #content.error .message,#trac-container div.system-message
{
  background:#fdc;
  border:2px solid #d00;
  color:#500;
  padding:.5em;
  margin:1em 0;
}

#trac-container #content.error div.message pre,#trac-container div.system-message pre
{
  margin-left:1em;
  overflow:hidden;
  white-space:normal;
}

#trac-container div.system-message p
{
  margin:0;
}

#trac-container div.system-message p.system-message-title
{
  font-weight:bold;
}

#trac-container #warning.system-message,#trac-container .warning.system-message
{
  background:#ffb;
  border:1px solid #000;
}

#trac-container #warning.system-message li
{
  list-style-type:square;
}

#trac-container #notice.system-message,#trac-container .notice.system-message
{
  background:#dfd;
  border:1px solid #000;
}

#trac-container #notice.system-message li
{
  list-style-type:square;
}

#trac-container #content.error form.newticket
{
  display:inline;
}

#trac-container #content.error form.newticket textarea
{
  display:none;
}

#trac-container #content.error #systeminfo,#trac-container #content.error #plugins
{
  margin:1em;
  width:auto;
}

#trac-container #content.error #systeminfo th,#trac-container #content.error #systeminfo td,#trac-container #content.error #plugins th,#trac-container #content.error #plugins td
{
  font-size:90%;
}

#trac-container #content.error #systeminfo th,#trac-container #content.error #plugins th
{
  background:#f7f7f7;
  font-weight:bold;
}

#trac-container #content.error #traceback
{
  margin-left:1em;
}

#trac-container #content.error #traceback :link,#trac-container #content.error #traceback :visited
{
  border:none;
}

#trac-container #content.error #tbtoggle
{
  font-size:80%;
}

#trac-container #content.error #traceback div
{
  margin-left:1em;
}

#trac-container #content.error #traceback h3
{
  font-size:95%;
  margin:.5em 0 0;
}

#trac-container #content.error #traceback :link var,#trac-container #content.error #traceback :visited var
{
  font-family:monospace;
  font-style:normal;
  font-weight:bold;
}

#trac-container #content.error #traceback span.file
{
  color:#666;
  font-size:85%;
}

#trac-container #content.error #traceback ul
{
  list-style:none;
  margin:.5em 0;
  padding:0;
}

#trac-container #content.error #traceback table.code td
{
  white-space:pre;
  font-size:90%;
}

#trac-container #content.error #traceback table.code tr.current td
{
  background:#e6e6e6;
}

#trac-container #content.error #traceback table
{
  margin:.5em 0 1em;
}

#trac-container #content.error #traceback th,#trac-container #content.error #traceback td
{
  font-size:85%;
  padding:1px;
}

#trac-container #content.error #traceback th var
{
  font-family:monospace;
  font-style:normal;
}

#trac-container #content.error #traceback td code
{
  white-space:pre;
}

#trac-container #content.error #traceback pre
{
  font-size:95%;
}

#trac-container #content.error #plugins td.file
{
  color:#666;
}

#trac-container #content .paging
{
  margin:0 0 2em;
  padding:.5em 0 0;
  font-size:85%;
  line-height:2em;
  text-align:center;
}

#trac-container #content .paging .current
{
  padding:.1em .3em;
  border:1px solid #333;
  background:#999;
  color:#fff;
}

#trac-container #content .paging :link,#trac-container #content .paging :visited
{
  padding:.1em .3em;
  border:1px solid #666;
  background:transparent;
  color:#666;
}

#trac-container #content .paging :link:hover,#trac-container #content .paging :visited:hover
{
  background:#999;
  color:#fff;
  border-color:#333;
}

#trac-container #content .paging .previous a,#trac-container #content .paging .next a
{
  font-size:150%;
  font-weight:bold;
  border:none;
}

#trac-container #content .paging .previous a:hover,#trac-container #content .paging .next a:hover
{
  background:transparent;
  color:#666;
}

#trac-container #content h2 .numresults
{
  color:#666;
  font-size:90%;
}

/* Styles for search word highlighting */
@media screen
{
  #trac-container .searchword0
{
    background:#ff9;
  }

  #trac-container .searchword1
{
    background:#cfc;
  }

  #trac-container .searchword2
{
    background:#cff;
  }

  #trac-container .searchword3
{
    background:#ccf;
  }

  #trac-container .searchword4
{
    background:#fcf;
  }

}

@media print
{
  #trac-container #header,#trac-container #altlinks,#trac-container #footer,#trac-container #help
{
    display:none;
  }

  #trac-container .nav,#trac-container form,#trac-container .buttons form,#trac-container form .buttons,#trac-container form .inlinebuttons,#trac-container .noprint,#trac-container .trac-nav,#trac-container .trac-topnav
{
    display:none;
  }

  #trac-container form.printableform
{
    display:block;
  }

}
