/* This file has been automatically generated by trac-rescope. Do not edit. */
@import url(code.css);
#trac-container #prefs .buttons
{
  margin-top:0;
}

#trac-container #prefs fieldset
{
  margin-left:1em;
  border:1px dotted #dfdfdf;
}

#trac-container #prefs fieldset legend
{
  margin:0;
  padding:2px;
}

#trac-container h1 .numrows,#trac-container h2 .numrows
{
  margin-left:1em;
  color:#999;
  font-size:65%;
  font-weight:normal;
}

#trac-container h2.report-result
{
  background:#f7f7f7;
  border-bottom:1px solid #d7d7d7;
  margin:2em 0 0;
  padding:0 .33em;
}

#trac-container #report-descr
{
  margin:0 2em;
  font-size:90%;
}

#trac-container #report-notfound
{
  margin:2em;
  font-size:110%;
}

#trac-container #content.report .field
{
  margin:1em 0;
}

#trac-container #content.report .field label
{
  padding-bottom:.3em;
}

#trac-container #query
{
  clear:right;
}

#trac-container #query fieldset,#trac-container #query fieldset input,#trac-container #query fieldset select
{
  font-size:11px;
}

#trac-container #query fieldset input[type="button"]
{
  padding:.1em .5em;
}

#trac-container #query fieldset
{
  margin-top:1em;
}

#trac-container #query fieldset.collapsed
{
  border-width:0;
  margin-bottom:0;
  padding:0 .5em;
}

#trac-container #query .option,#trac-container #query .option input,#trac-container #query .option select
{
  font-size:11px;
}

#trac-container #query .option
{
  float:left;
  line-height:2em;
  margin:.9em 2.5em 0 .5em;
  padding:0 0 .1em;
}

#trac-container #query .buttons
{
  float:right;
  margin-top:.5em;
}

#trac-container #query .buttons input
{
  margin:.5em;
}

#trac-container #query hr
{
  clear:both;
  margin:0;
  visibility:hidden;
}

#trac-container #filters table
{
  width:100%;
}

#trac-container #filters td.trac-clause
{
  padding:0;
}

#trac-container #filters td .trac-clause-lsep
{
  float:left;
  width:47%;
  line-height:50%;
}

#trac-container #filters td .trac-clause-msep
{
  float:left;
  text-align:center;
  width:5%;
}

#trac-container #filters td .trac-clause-rsep
{
  float:right;
  width:47%;
  line-height:50%;
}

#trac-container #filters td hr
{
  margin:1px;
  visibility:visible;
}

#trac-container #filters tr
{
  height:2em;
}

#trac-container #filters th,#trac-container #filters td
{
  padding:0 .2em;
  vertical-align:middle;
}

#trac-container #filters th
{
  font-size:11px;
  text-align:right;
  white-space:nowrap;
}

#trac-container #filters td label
{
  font-size:11px;
}

#trac-container #filters td.mode
{
  text-align:right;
}

#trac-container #filters td.filter
{
  width:100%;
}

#trac-container #filters td.filter label.control
{
  padding-right:1em;
}

#trac-container #filters td.and
{
  white-space:nowrap;
}

#trac-container #filters td.or
{
  text-align:right;
  white-space:nowrap;
}

#trac-container #filters div.inlinebuttons
{
  display:inline;
}

#trac-container #columns div label
{
  display:block;
  float:left;
  padding:0 1em .5em 0;
}

/* Styles for the report list and the report results table
   (extends the styles for "table.listing") */
#trac-container .reports td.title
{
  width:100%;
  white-space:normal;
}

#trac-container .reports td.action
{
  white-space:nowrap;
}

#trac-container .tickets tbody:first-child tr.trac-group h2
{
  margin-top:0;
}

#trac-container .tickets tr.trac-group
{
  border:none;
}

#trac-container .tickets tr.trac-group:hover
{
  background:none !important;
}

#trac-container .tickets tr.trac-group th
{
  background:none;
  border:none;
  padding:0 0 1em;
}

#trac-container .tickets tr.trac-columns th
{
  background:#f7f7f0;
}

#trac-container .tickets tr.trac-columns th
{
  border:1px solid #d7d7d7;
  border-bottom-color:#999;
  font-size:11px;
  font-weight:bold;
  padding:2px .5em;
  vertical-align:bottom;
  white-space:nowrap;
}

#trac-container .tickets tr.trac-columns th :link:hover,#trac-container .tickets tr.trac-columns th :visited:hover
{
  background-color:transparent;
}

#trac-container .tickets tr.trac-columns th a
{
  border:none;
  padding-right:12px;
}

#trac-container .tickets tr.trac-columns th,#trac-container .reports tr.trac-columns th
{
  text-transform:capitalize;
  white-space:nowrap;
}

#trac-container .tickets tbody td,#trac-container .reports tbody td
{
  padding:.1em .5em !important;
}

#trac-container .tickets tbody td a,#trac-container .reports tbody td a
{
  border-bottom:none;
}

#trac-container .tickets tbody td.id :link,#trac-container .tickets tbody td.id :visited
{
  font-weight:bold;
}

#trac-container .tickets tbody td.time a,#trac-container .tickets tbody td.changetime a
{
  white-space:nowrap;
}

#trac-container .tickets tbody tr
{
  border-bottom:1px solid #ddd;
}

#trac-container .tickets tbody tr:hover
{
  background:#eed;
  color:#000;
}

#trac-container .tickets tr.color1-odd
{
  background:#fdc;
  border-color:#e88;
  color:#a22;
}

#trac-container .tickets tr.color1-even
{
  background:#fed;
  border-color:#e99;
  color:#a22;
}

#trac-container .tickets tr.color2-odd
{
  background:#ffb;
  border-color:#eea;
  color:#880;
}

#trac-container .tickets tr.color2-even
{
  background:#ffd;
  border-color:#dd8;
  color:#880;
}

#trac-container .tickets tr.color3-odd
{
  background:#fbfbfb;
  border-color:#ddd;
  color:#444;
}

#trac-container .tickets tr.color3-even
{
  background:#f6f6f6;
  border-color:#ccc;
  color:#333;
}

#trac-container .tickets tr.color4-odd
{
  background:#e7ffff;
  border-color:#cee;
  color:#099;
}

#trac-container .tickets tr.color4-even
{
  background:#dff;
  border-color:#bee;
  color:#099;
}

#trac-container .tickets tr.color5-odd
{
  background:#e7eeff;
  border-color:#cde;
  color:#469;
}

#trac-container .tickets tr.color5-even
{
  background:#dde7ff;
  border-color:#cde;
  color:#469;
}

#trac-container .tickets tr.color6-odd
{
  background:#f0f0f0;
  border-color:#ddd;
  color:#888;
}

#trac-container .tickets tr.color6-even
{
  background:#f7f7f7;
  border-color:#ddd;
  color:#888;
}

#trac-container .tickets tr.color6-odd a,#trac-container .color6-even a
{
  color:#b66;
}

#trac-container .tickets tbody tr.fullrow td,#trac-container .tickets tbody td.fullrow
{
  border:none;
  color:#333;
  background:transparent;
  padding:0 1em !important;
  /* Opera 9 is *very* sensitive with this */
  font-size:85%;
}

#trac-container .tickets tbody tr.fullrow:hover
{
  background:transparent !important;
}

#trac-container .tickets .fullrow :link,#trac-container .tickets .fullrow :visited
{
  display:inline;
}

#trac-container .tickets .fullrow .meta
{
  color:#999;
}

#trac-container .tickets .fullrow hr
{
  display:none;
}

/* Query results table */
#trac-container table.tickets tbody tr.added td
{
  font-weight:bold;
}

#trac-container table.tickets tbody tr.changed td
{
  font-style:italic;
}

#trac-container table.tickets tbody tr.removed td
{
  color:#999;
}

body #trac-container table.tickets tbody tr.prio1
{
  background:#fdc;
  border-color:#e88;
}

body #trac-container table.tickets tbody tr.even.prio1
{
  background:#fed;
  border-color:#e99;
}

body #trac-container table.tickets tbody tr.prio2
{
  background:#ffb;
  border-color:#eea;
}

body #trac-container table.tickets tbody tr.even.prio2
{
  background:#ffd;
  border-color:#dd8;
}

body #trac-container table.tickets tbody tr.prio3
{
  background:#fbfbfb;
  border-color:#ddd;
}

body #trac-container table.tickets tbody tr.even.prio3
{
  background:#f6f6f6;
  border-color:#ccc;
}

body #trac-container table.tickets tbody tr.prio4
{
  background:#e7ffff;
  border-color:#cee;
}

body #trac-container table.tickets tbody tr.even.prio4
{
  background:#dff;
  border-color:#bee;
}

body #trac-container table.tickets tbody tr.prio5
{
  background:#e7eeff;
  border-color:#cde;
}

body #trac-container table.tickets tbody tr.even.prio5
{
  background:#dde7ff;
}

body #trac-container table.tickets tbody tr.prio6
{
  background:#f0f0f0;
  border-color:#ddd;
}

body #trac-container table.tickets tbody tr.even.prio6
{
  background:#f7f7f7;
}

#trac-container table.tickets tbody tr.fullrow th
{
  border:none;
  vertical-align:middle;
  text-align:center;
  font-size:85%;
}
